@@ -1,6 +1,7 @@
 import re
 # local files
 from . import replace_regex_matches
+from .badge_html import generate_badge_html
 
 
 # |"badge name":value|
@@ -10,14 +11,7 @@ REGEX = re.compile('\|"([^"]+)":([^\|]+)\|')
 def replace_function(match: re.Match) -> str:
     badge_type = match.group(1)
     badge_value = match.group(2)
-    return normal_badge(badge_type, badge_value)
-
-
-def normal_badge(badge_type: str, badge_value: str) -> str:
-    return ("<span class='badge'>"+
-        f"<span class=title>{badge_type}</span>"+
-        f"<span class=value>{badge_value}</span>"+
-    "</span>")
+    return generate_badge_html(badge_type, badge_value)
 
 
 def replace_normal_badges(text: str) -> str:
